@@ -107,4 +107,10 @@ class LivenessFaceVerifyRequest(RpcRequest):
 		return self.get_query_params().get('Model')
 
 	def set_Model(self,Model):
-		self.add_query_param('Model',Model)
\ No newline at end of file
+		self.add_query_param('Model',Model)
+
+	def get_Crop(self):
+		return self.get_body_params().get('Crop')
+
+	def set_Crop(self,Crop):
+		self.add_body_params('Crop', Crop)
\ No newline at end of file
